
# Nucleus
The Ultimate IDE for Bioinformaticians

"A tool tailored for bioinformaticians—just as software developers have Visual Studio Code, bioinformaticians have Nucleus."


![Demo of the tool](assets/demo.gif)

## Getting started

You can get started quickly like this:

```
pip install -r requirements.txt

cd nucleus
```

To set the `OPENAI_API_KEY` environment variable.
```
export OPENAI_API_KEY="sk-...."
```

To run
```python
python nucleus.py
```

## Features
- [x] Based on query provide commands related to bioinformatic tools.
- [x] Execute the command.
- [x] suggest filenames on tab-press while query input.
- [x] Able to execute normal terminal commands as well as commands sent as query.
- [ ] local severs spinoff with chat interface.
- [ ] Visualization of bio-files. spin off jbrowse component.
